# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/ready-steady-go',
                'doc_host': 'https://xl0.github.io',
                'git_url': 'https://github.com/xl0/ready-steady-go',
                'lib_path': 'ready_steady_go'},
  'syms': { 'ready_steady_go.benchmark': { 'ready_steady_go.benchmark.benchmark': ( 'benchmark.html#benchmark',
                                                                                    'ready_steady_go/benchmark.py')},
            'ready_steady_go.cli': {'ready_steady_go.cli.cli': ('cli.html#cli', 'ready_steady_go/cli.py')}}}